<?php

/**
 * execute the auth process
 * - verification of the signature
 *
 * @param string $address
 * @param string $params
 *
 * @return array
 */

use QUI\System\Log;

QUI::$Ajax->registerFunction(
    'package_quiqqer_authmetamask_ajax_auth',
    function ($address, $signature, $host) {
        if (empty($address) || empty($signature) || empty($host)) {
            return false;
        }

        $result = QUI::getDataBase()->fetch([
            'from' => QUI\MetaMask\MetaMask::table(),
            'where' => [
                'address' => $address
            ],
            'limit' => 1
        ]);

        if (!isset($result[0])) {
            throw new Exception('Permission denied');
        }

        $message = QUI::getLocale()->get('quiqqer/authmetamask', 'signing.message', [
            'host' => $host,
            'nonce' => $result[0]['nonce']
        ]);

        if (!is_string($message)) {
            throw new Exception('Permission denied');
        }

        try {
            $MetaMaskAuth = new QUI\Auth\MetaMask\Auth();

            $MetaMaskAuth->auth([
                'message' => $message,
                'signature' => $signature,
                'address' => $address
            ]);

            $MetaMaskAuth->setSession($address);
            $User = QUI::getUserBySession();

            return [
                'userId' => $User->getId(),
                'uniqueId' => $User->getUniqueId(),
                'username' => $User->getUsername()
            ];
        } catch (QUI\Auth\MetaMask\Exception $Exception) {
            Log::addError($Exception->getMessage());
            return false;
        }
    },
    ['address', 'signature', 'host']
);
