<?php

/**
 * This file contains QUI\MetaMask\MetaMask
 */

namespace QUI\MetaMask;

use QUI;

/**
 * Class MetaMask
 *
 * @package QUI\MetaMask
 */
class MetaMask
{
    /**
     * @return string
     */
    public static function table(): string
    {
        return QUI::getDBTableName('quiqqer_auth_eth');
    }

    /**
     * Return the user id via the eth address
     *
     * @param $address
     * @return int
     *
     * @throws QUI\Users\UserAuthException
     */
    public static function getUserIdByEthAddress($address): int
    {
        try {
            $result = QUI::getDataBase()->fetch([
                'from' => self::table(),
                'where' => [
                    'address' => $address
                ],
                'limit' => 1
            ]);
        } catch (\Exception) {
            throw new QUI\Users\UserAuthException('User not found', 404);
        }

        if (!isset($result[0])) {
            throw new QUI\Users\UserAuthException('User not found', 404);
        }

        if ((int)$result[0]['userId']) {
            return (int)$result[0]['userId'];
        }

        throw new QUI\Users\UserAuthException('User not found', 404);
    }

    /**
     * Return the eth address of an user-id
     *
     * @param $userId
     * @return string|false
     */
    public static function getUserEthAddress($userId): bool | string
    {
        try {
            $result = QUI::getDataBase()->fetch([
                'from' => self::table(),
                'where' => [
                    'userId' => $userId
                ],
                'limit' => 1
            ]);
        } catch (\Exception $Exception) {
            QUI\System\Log::writeException($Exception);

            return false;
        }

        if (isset($result[0])) {
            return $result[0]['address'];
        }

        return false;
    }
}
