<?php

namespace QUI\Registration\MetaMask;

use QUI;
use QUI\FrontendUsers;
use QUI\FrontendUsers\InvalidFormField;

/**
 * Class Registrar
 */
class Registrar extends FrontendUsers\AbstractRegistrar
{
    /**
     * Registrar constructor.
     */
    public function __construct()
    {
        $this->setAttribute('icon-css-class', 'metamask-registrar');
    }

    /**
     * @param QUI\Interfaces\Users\User $User
     * @return void
     */
    public function onRegistered(QUI\Interfaces\Users\User $User): void
    {
    }

    /**
     * Return the success message
     * @return string
     */
    public function getSuccessMessage(): string
    {
        return '';
    }

    public function validate(): array
    {
        return [];
    }

    /**
     * Get all invalid registration form fields
     *
     * @return InvalidFormField[]
     */
    public function getInvalidFields(): array
    {
        // Registration via MetaMask account does not use form fields
        return [];
    }

    /**
     * @return string
     */
    public function getUsername(): string
    {
        return '';
    }

    /**
     * @return RegistrationControl
     */
    public function getControl(): QUI\Control
    {
        return new RegistrationControl();
    }

    /**
     * Get title
     *
     * @param QUI\Locale|null $Locale (optional) - If omitted use QUI::getLocale()
     * @return string
     */
    public function getTitle(null | QUI\Locale $Locale = null): string
    {
        if (is_null($Locale)) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/authmetamask', 'registrar.title');
    }

    /**
     * Get description
     *
     * @param QUI\Locale|null $Locale (optional) - If omitted use QUI::getLocale()
     * @return string
     */
    public function getDescription(null | QUI\Locale $Locale = null): string
    {
        if (is_null($Locale)) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/authmetamask', 'registrar.description');
    }

    /**
     * @return string
     */
    public function getIcon(): string
    {
        return URL_OPT_DIR . 'quiqqer/authmetamask/bin/MetaMaskLogo.png';
    }

    /**
     * Check if this Registrar can send passwords
     *
     * @return bool
     */
    public function canSendPassword(): bool
    {
        return false;
    }
}
